package edu.nyu.scps.swipe;
import android.content.Context;
import android.graphics.Canvas;
import android.util.DisplayMetrics;
import android.view.Display;
import android.view.MotionEvent;
import android.view.WindowManager;
import android.widget.TextView;


public class SwipeView extends TextView {

	int width, height;	//in pixels of the SwipeView
	
	MotionEvent downEvent;	//start of swipe
	MotionEvent moveEvent;	//current location of swipe

	public SwipeView(Context context) {
		super(context);
		setTextSize(20);	//default is 14
	}
	
	public void touch(MotionEvent event) {
		switch(event.getAction()) {
		case MotionEvent.ACTION_DOWN:
			downEvent = MotionEvent.obtain(event);	//copy it
			return;
			
		case MotionEvent.ACTION_UP:
			downEvent = null;
			return;
			
		case MotionEvent.ACTION_MOVE:
			moveEvent = event;
			break;
			
		default:
			return;
		}
		
		final float horizontal = moveEvent.getX() - downEvent.getX();
		final float vertical = moveEvent.getY() - downEvent.getY();
		final float distance = (float)Math.hypot(horizontal, vertical);
		final float angle = (float)(Math.atan2(-vertical, horizontal) * 180 / Math.PI);
		final float duration = (moveEvent.getEventTime() - downEvent.getEventTime()) / 1000.0f;

		setText(
			"start: (" + downEvent.getX() + ", " + downEvent.getY() + ")\n"
			+ "current: (" + moveEvent.getX() + ", " + moveEvent.getY() + ")\n"
			+ "horizontal distance:" + horizontal + " pixels\n"
			+ "vertical distance:" + vertical + " pixels\n"
			+ "total distance:" + distance + " pixels\n"
			+ "angle:" + angle + "\n"
			+ "duration:" + duration + " seconds\n"
		);
		
		if (duration != 0) {
			append("speed:" + distance / duration + " pixels per second\n");
		}
		
		if (distance < 50) {
			append("too short to be a swipe");
		} else if (angle <= -135) {
			append("left swipe");
		} else if (angle <= -45) {
			append("down swipe");
		} else if (angle <= 45) {
			append("right swipe");
		} else if (angle <= 135) {
			append("up swipe");
		} else {
			append("left swipe");
		}
		
		invalidate();
	}
}
